@@ -86,8 +86,10 @@ def load_rerank_data(default_input, load_default_text=True):
             return all_lines_to_pandas(input_file, load_default_text)
 
 
-def persist_and_normalize_run(run, system_name, depth, output_file):
-    run.to_csv(filename, sep=" ", header=False, index=False)
+def persist_and_normalize_run(run, system_name, output_file, depth=1000):
+    if not output_file.endswith('run.txt'):
+        output_file = output_file + '/run.txt'
+    normalize_run(run, system_name, depth).to_csv(output_file, sep=" ", header=False, index=False)
 
 
 def normalize_run(run, system_name, depth=1000):
@@ -102,7 +104,7 @@ def normalize_run(run, system_name, depth=1000):
     if 'Q0' not in run.columns:
         run['Q0'] = 0
 
-    run = run.groupby("qid")[["qid", "Q0", "docno", "rank", "score", "system"]].head(1000)
+    run = run.groupby("qid")[["qid", "Q0", "docno", "score", "system"]].head(depth)
 
     # Make sure that rank position starts by 1
     run["rank"] = 1
